@@ -3,6 +3,7 @@
 
 /*
  * Copyright (C) 2001 Havoc Pennington
+ * Copyright (C) 2003, 2005-2007 Vincent Untz
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,6 +21,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if !defined (__LIBWNCK_H_INSIDE__) && !defined (WNCK_COMPILATION)
+#error "Only <libwnck/libwnck.h> can be included directly."
+#endif
+
 #ifndef WNCK_PAGER_H
 #define WNCK_PAGER_H
 
@@ -79,7 +84,7 @@ typedef enum {
 
 GType wnck_pager_get_type (void) G_GNUC_CONST;
 
-GtkWidget* wnck_pager_new (WnckScreen *screen);
+GtkWidget* wnck_pager_new (void);
 
 gboolean wnck_pager_set_orientation (WnckPager         *pager,
 				     GtkOrientation     orientation);
@@ -92,14 +97,6 @@ void wnck_pager_set_show_all     (WnckPager            *pager,
 void wnck_pager_set_shadow_type  (WnckPager	       *pager,
 				  GtkShadowType		shadow_type);
 
-
-#ifndef WNCK_DISABLE_DEPRECATED
-void wnck_pager_set_screen       (WnckPager            *pager,
-				  WnckScreen           *screen);
-#endif /* WNCK_DISABLE_DEPRECATED */
-
 G_END_DECLS
 
 #endif /* WNCK_PAGER_H */
-
-
